/*
Copyright The Kubernetes Authors.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

// Code generated by client-gen. DO NOT EDIT.

package v1beta1

import (
	"context"
	"time"

	v1beta1 "github.com/linkerd/linkerd2/controller/gen/apis/serverauthorization/v1beta1"
	scheme "github.com/linkerd/linkerd2/controller/gen/client/clientset/versioned/scheme"
	v1 "k8s.io/apimachinery/pkg/apis/meta/v1"
	types "k8s.io/apimachinery/pkg/types"
	watch "k8s.io/apimachinery/pkg/watch"
	rest "k8s.io/client-go/rest"
)

// ServerAuthorizationsGetter has a method to return a ServerAuthorizationInterface.
// A group's client should implement this interface.
type ServerAuthorizationsGetter interface {
	ServerAuthorizations(namespace string) ServerAuthorizationInterface
}

// ServerAuthorizationInterface has methods to work with ServerAuthorization resources.
type ServerAuthorizationInterface interface {
	Create(ctx context.Context, serverAuthorization *v1beta1.ServerAuthorization, opts v1.CreateOptions) (*v1beta1.ServerAuthorization, error)
	Update(ctx context.Context, serverAuthorization *v1beta1.ServerAuthorization, opts v1.UpdateOptions) (*v1beta1.ServerAuthorization, error)
	Delete(ctx context.Context, name string, opts v1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error
	Get(ctx context.Context, name string, opts v1.GetOptions) (*v1beta1.ServerAuthorization, error)
	List(ctx context.Context, opts v1.ListOptions) (*v1beta1.ServerAuthorizationList, error)
	Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ServerAuthorization, err error)
	ServerAuthorizationExpansion
}

// serverAuthorizations implements ServerAuthorizationInterface
type serverAuthorizations struct {
	client rest.Interface
	ns     string
}

// newServerAuthorizations returns a ServerAuthorizations
func newServerAuthorizations(c *ServerauthorizationV1beta1Client, namespace string) *serverAuthorizations {
	return &serverAuthorizations{
		client: c.RESTClient(),
		ns:     namespace,
	}
}

// Get takes name of the serverAuthorization, and returns the corresponding serverAuthorization object, and an error if there is any.
func (c *serverAuthorizations) Get(ctx context.Context, name string, options v1.GetOptions) (result *v1beta1.ServerAuthorization, err error) {
	result = &v1beta1.ServerAuthorization{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("serverauthorizations").
		Name(name).
		VersionedParams(&options, scheme.ParameterCodec).
		Do(ctx).
		Into(result)
	return
}

// List takes label and field selectors, and returns the list of ServerAuthorizations that match those selectors.
func (c *serverAuthorizations) List(ctx context.Context, opts v1.ListOptions) (result *v1beta1.ServerAuthorizationList, err error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	result = &v1beta1.ServerAuthorizationList{}
	err = c.client.Get().
		Namespace(c.ns).
		Resource("serverauthorizations").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Do(ctx).
		Into(result)
	return
}

// Watch returns a watch.Interface that watches the requested serverAuthorizations.
func (c *serverAuthorizations) Watch(ctx context.Context, opts v1.ListOptions) (watch.Interface, error) {
	var timeout time.Duration
	if opts.TimeoutSeconds != nil {
		timeout = time.Duration(*opts.TimeoutSeconds) * time.Second
	}
	opts.Watch = true
	return c.client.Get().
		Namespace(c.ns).
		Resource("serverauthorizations").
		VersionedParams(&opts, scheme.ParameterCodec).
		Timeout(timeout).
		Watch(ctx)
}

// Create takes the representation of a serverAuthorization and creates it.  Returns the server's representation of the serverAuthorization, and an error, if there is any.
func (c *serverAuthorizations) Create(ctx context.Context, serverAuthorization *v1beta1.ServerAuthorization, opts v1.CreateOptions) (result *v1beta1.ServerAuthorization, err error) {
	result = &v1beta1.ServerAuthorization{}
	err = c.client.Post().
		Namespace(c.ns).
		Resource("serverauthorizations").
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(serverAuthorization).
		Do(ctx).
		Into(result)
	return
}

// Update takes the representation of a serverAuthorization and updates it. Returns the server's representation of the serverAuthorization, and an error, if there is any.
func (c *serverAuthorizations) Update(ctx context.Context, serverAuthorization *v1beta1.ServerAuthorization, opts v1.UpdateOptions) (result *v1beta1.ServerAuthorization, err error) {
	result = &v1beta1.ServerAuthorization{}
	err = c.client.Put().
		Namespace(c.ns).
		Resource("serverauthorizations").
		Name(serverAuthorization.Name).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(serverAuthorization).
		Do(ctx).
		Into(result)
	return
}

// Delete takes name of the serverAuthorization and deletes it. Returns an error if one occurs.
func (c *serverAuthorizations) Delete(ctx context.Context, name string, opts v1.DeleteOptions) error {
	return c.client.Delete().
		Namespace(c.ns).
		Resource("serverauthorizations").
		Name(name).
		Body(&opts).
		Do(ctx).
		Error()
}

// DeleteCollection deletes a collection of objects.
func (c *serverAuthorizations) DeleteCollection(ctx context.Context, opts v1.DeleteOptions, listOpts v1.ListOptions) error {
	var timeout time.Duration
	if listOpts.TimeoutSeconds != nil {
		timeout = time.Duration(*listOpts.TimeoutSeconds) * time.Second
	}
	return c.client.Delete().
		Namespace(c.ns).
		Resource("serverauthorizations").
		VersionedParams(&listOpts, scheme.ParameterCodec).
		Timeout(timeout).
		Body(&opts).
		Do(ctx).
		Error()
}

// Patch applies the patch and returns the patched serverAuthorization.
func (c *serverAuthorizations) Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts v1.PatchOptions, subresources ...string) (result *v1beta1.ServerAuthorization, err error) {
	result = &v1beta1.ServerAuthorization{}
	err = c.client.Patch(pt).
		Namespace(c.ns).
		Resource("serverauthorizations").
		Name(name).
		SubResource(subresources...).
		VersionedParams(&opts, scheme.ParameterCodec).
		Body(data).
		Do(ctx).
		Into(result)
	return
}
